@@ -346,12 +346,14 @@ class MapTiles(RanaModule):
                         sprint = self._realDebugLog
                     else:
                         sprint = self._fakeDebugLog
+                    sprint("looking for tile %s", lzxy)
                     tileData = self._storeTiles.getTileData(lzxy)
                     if not tileData:  # TODO: is this actually needed ?
+                        sprint("tile not found locally %s", lzxy)
                         # tile not found locally and needs to be downloaded from network
                         # Are we allowed to download it ? (network=='full')
                         if self.get('network', 'full') == 'full':
-                            sprint("automatic tile download enabled - adding download request")
+                            sprint("auto tile dl enabled - adding dl request for %s", lzxy)
                             # switch the status tile to "Waiting for download slot"
                             if self.cacheImageSurfaces:
                                 with self.imagesLock:
@@ -365,15 +367,15 @@ class MapTiles(RanaModule):
                                 # - if it is in view, new download request will be added
                                 lzxy, tag = droppedRequest
                                 name = self.imageName(lzxy)
-                                sprint("old download request dropped from work request stack:")
-                                sprint(name)
+                                sprint("old download request dropped from work request stack: %s", name)
                                 self.removeImageFromMemory(name)
                                 # also notify any listener that tha tile has been processed
                                 self.tileDownloaded(constants.TILE_DOWNLOAD_QUEUE_FULL, droppedRequest[0], droppedRequest[1])
                         else:
-                            sprint("automatic tile download disabled - not adding download request")
+                            sprint("auto tile dl disabled - not adding dl request for %s", lzxy)
                     else:
                         # tile found locally and not downloaded, trigger the downloaded signal
+                        sprint("%s found locally", lzxy)
                         self.tileDownloaded(True, lzxy, tag)
                         # and cache it in memory
                         if self.cacheImageSurfaces:
@@ -741,12 +743,12 @@ class MapTiles(RanaModule):
         # Return to the cairo projection to what it was before
         cr.restore()
 
-    def _fakeDebugLog(self, text):
+    def _fakeDebugLog(self, *argv):
         """Log function that does nothing"""
         pass
 
-    def _realDebugLog(self, text):
-        self.log.debug(text)
+    def _realDebugLog(self, *argv):
+        self.log.debug(*argv)
 
     def _getLayerById(self, layerId):
         """Get layer description from the mapLayers module"""
@@ -763,23 +765,31 @@ class MapTiles(RanaModule):
 
         # at this point, there is only a placeholder image in the image cache
         sprint("###")
-        sprint("loading tile %s" % self.getTileName(lzxy))
+        tileName = self.getTileName(lzxy)
+        sprint("loading tile %s", tileName)
 
         # is the tile in local storage ?
         start1 = time.clock()
-        pixbuf = self._storeTiles.getTile(lzxy)
+        tileData = self._storeTiles.getTileData(lzxy)
 
-        # None from getTiles means the tile was not found
-        # False means loading the tile from file to pixbuf failed
-        if pixbuf:
-            start2 = time.clock()
-            self.storeInMemory(self.pixbuf2cairoImageSurface(pixbuf), self.getTileName(lzxy))
-            if debug:
-                storageType = self.get('tileStorageType', 'files')
-                sprint(
-                    "tile loaded from local storage (%s) in %1.2f ms" % (storageType, (1000 * (time.clock() - start1))))
-                sprint("tile cached in memory in %1.2f ms" % (1000 * (time.clock() - start2)))
-            return True
+        if tileData:
+            try:
+                pixbuf = self.data2pixbuf(tileData)
+            except Exception:
+                self.log.exception("loading tile image to pixbuf failed, name: %s", tileName)
+                return False
+        else:
+            sprint("tile name not found: %s", tileName)
+            return False
+
+        start2 = time.clock()
+        self.storeInMemory(self.pixbuf2cairoImageSurface(pixbuf), self.getTileName(lzxy))
+        if debug:
+            storageType = self.get('tileStorageType', 'files')
+            sprint(
+                "tile loaded from local storage (%s) in %1.2f ms" % (storageType, (1000 * (time.clock() - start1))))
+            sprint("tile cached in memory in %1.2f ms" % (1000 * (time.clock() - start2)))
+        return True
 
     def loadImageFromFile(self, path, name, imageType="normal", expireTimestamp=None, dictIndex=0):
         pixbuf = gtk.gdk.pixbuf_new_from_file(path)
